@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tomlparse" "1.0.0"
+(define-package "tomlparse" "20250512.1937"
   "A straight-forward tree sitter based parser for toml data."
   '((emacs "29.1"))
   :url "https://github.com/johannes-mueller/tomlparse.el"
